@@ -372,77 +372,79 @@ for (i.pops in 1:length(POPS))
 			dimnames=list(c("Inac.L", "Inac.S", "Inac.perc.L", "Inac.perc.S", "TotalInacINTRA", "Mean2Stand.TotalInacINTRA"),POPS[i]))
 			
 		
-		if(sanchez)
-			{
-			input<-input[,-c(match("origindist",colnames(input)))]
+          if(sanchez)
+          {
+            input<-input[,-c(match("origindist",colnames(input)))]
 
-			## Sanchez index
-			subsetST<-input[input$sexorg=="ST",]
-			distST.2 = sqrt((subsetST$x)^2+(subsetST$y)^2+(subsetST$z)^2) # para subset sexorg==ST
+            ## Sanchez index
+            subsetST<-input[input$sexorg=="ST",]
+            distST.2 = sqrt((subsetST$x)^2+(subsetST$y)^2+(subsetST$z)^2) # para subset sexorg==ST
 
-			subsetAN<-input[input$sexorg=="AN",]
-			distAN.2 = sqrt((subsetAN$x)^2+(subsetAN$y)^2+(subsetAN$z)^2) #  para subset sexorg==AN
+            subsetAN<-input[input$sexorg=="AN",]
+            distAN.2 = sqrt((subsetAN$x)^2+(subsetAN$y)^2+(subsetAN$z)^2) #  para subset sexorg==AN
 
-			n.2= nrow(input[which(input$morph=="L" & input$sexorg=="ST"),]) # 	num rows morfo==L & sexorg==ST
-			m.2= nrow(input[which(input$morph=="S" & input$sexorg=="AN"),]) # num rows morfo==S & sexorg==AN
-			p.2= nrow(input[which(input$morph=="L" & input$sexorg=="AN"),]) #num rows morfo==L & sexorg==AN
-			q.2= nrow(input[which(input$morph=="S" & input$sexorg=="ST"),]) #m.2= num rows morfo==S & sexorg==ST
-			avdistAN.2= mean(distAN.2, na.rm=na.rm)
-			avdistST.2= mean(distST.2, na.rm=na.rm)
-			Xr.2=mean(c(avdistAN.2,avdistST.2), na.rm=na.rm)
+            n.2= nrow(input[which(input$morph=="L" & input$sexorg=="ST"),]) # num rows morfo==L & sexorg==ST
+            m.2= nrow(input[which(input$morph=="S" & input$sexorg=="AN"),]) # num rows morfo==S & sexorg==AN
+            p.2= nrow(input[which(input$morph=="L" & input$sexorg=="AN"),]) # num rows morfo==L & sexorg==AN
+            q.2= nrow(input[which(input$morph=="S" & input$sexorg=="ST"),]) # num rows morfo==S & sexorg==ST
+            avdistAN.2= mean(distAN.2, na.rm=na.rm)
+            avdistST.2= mean(distST.2, na.rm=na.rm)
+            Xr.2=mean(c(avdistAN.2,avdistST.2), na.rm=na.rm)
 
-			### For UP level
+            ### For L MORPH
 
-			par1 <- input[which(input$"morph"=="L" & input$"sexorg"=="ST"),]
-			par2 <- input[which(input$"morph"=="S" & input$"sexorg"=="AN"),]
+            par1 <- input[which(input$"morph"=="L" & input$"sexorg"=="ST"),]
+            par2 <- input[which(input$"morph"=="L" & input$"sexorg"=="AN"),]
 
-			df.2u<-c()
-			for (i.2 in 1:nrow(par1))
-			for (j.2 in 1:nrow(par2))
-				{
-				df.2u<-rbind(df.2u,cbind(par1[i.2,],par2[j.2,]))
-				}
+            df.2u<-c()
+            for (i.2 in 1:nrow(par1))
+              for (j.2 in 1:nrow(par2))
+              {
+                df.2u<-rbind(df.2u,cbind(par1[i.2,],par2[j.2,]))
+              }
 
-			colnames(df.2u)<-c("pop_code_mum","morph_mum","IDmum_L","ID_stigma","sexorg_mum", "upstigmaX","upstigmaY","upstigmaZ","pop_code_dad","morph_dad", "IDdad_S", "ID_anther",
-			"sexorg_dad","upantherX","upantherY","upantherZ")
-			df.2u$dist.2u <- sqrt((df.2u$upstigmaX-df.2u$upantherX)^2+(df.2u$upstigmaY-df.2u$upantherY)^2+(df.2u$upstigmaZ-df.2u$upantherZ)^2)
-			df.2u$distX.2u <-  df.2u$dist.2u/Xr.2
-			rL.2u <- sum(df.2u$distX.2u, na.rm=na.rm)/(n.2*m.2)
-			distXrL.2u <- (df.2u$distX.2u-rL.2u)^2
-			sdrL.2u <- sqrt(sum(distXrL.2u, na.rm=na.rm)/(n.2*m.2))
+            colnames(df.2u)<-c("pop_code_mum","morph_mum","IDmum_L","ID_stigma","sexorg_mum", "LstigmaX","LstigmaY","LstigmaZ","pop_code_dad","morph_dad", "IDdad_L", "ID_anther",
+                               "sexorg_dad","LantherX","LantherY","LantherZ")
 
-			## For DOWN level
+            df.2u$dist.2u <- sqrt((df.2u$LstigmaX-df.2u$LantherX)^2+(df.2u$LstigmaY-df.2u$LantherY)^2+(df.2u$LstigmaZ-df.2u$LantherZ)^2)
+            df.2u$distX.2u <-  df.2u$dist.2u/Xr.2
+            rL.2u <- sum(df.2u$distX.2u, na.rm=na.rm)/(n.2*m.2)
+            distXrL.2u <- (df.2u$distX.2u-rL.2u)^2
+            sdrL.2u <- sqrt(sum(distXrL.2u, na.rm=na.rm)/(n.2*m.2))
 
-			par1 <- input[which(input$"morph"=="S" & input$"sexorg"=="ST"),]
-			par2 <- input[which(input$"morph"=="L" & input$"sexorg"=="AN"),]
+            ### For S MORPH
 
-			df.2d<-c()
-			for (i.3 in 1:nrow(par1))
-			for (j.3 in 1:nrow(par2))
-			{
-			df.2d<-rbind(df.2d,cbind(par1[i.3,],par2[j.3,]))
-			}
+            par1 <- input[which(input$"morph"=="S" & input$"sexorg"=="ST"),]
+            par2 <- input[which(input$"morph"=="S" & input$"sexorg"=="AN"),]
 
-			colnames(df.2d)<-c("pop_code_mum","morph_mum","IDmum_S","ID_stigma","sexorg_mum", "downstigmaX","downstigmaY","downstigmaZ","pop_code_dad","morph_dad", "IDdad_L", "ID_anther",
-			"sexorg_dad","downantherX","downantherY","downantherZ")
+            df.2d<-c()
+            for (i.3 in 1:nrow(par1))
+              for (j.3 in 1:nrow(par2))
+              {
+                df.2d<-rbind(df.2d,cbind(par1[i.3,],par2[j.3,]))
+              }
 
-			df.2d$dist.2d <- sqrt((df.2d$downstigmaX-df.2d$downantherX)^2+(df.2d$downstigmaY-df.2d$downantherY)^2+(df.2d$downstigmaZ-df.2d$downantherZ)^2)
-			df.2d$distX.2d <- df.2d$dist.2d/Xr.2
-			rS.2d <- sum(df.2d$distX.2d, na.rm=na.rm)/(p.2*q.2)
-			distXrS.2d <- (df.2d$distX.2d-rS.2d)^2
-			sdrS.2d <- sqrt(sum(distXrS.2d, na.rm=na.rm)/(p.2*q.2))  ###corrected sqrt
+            colnames(df.2d)<-c("pop_code_mum","morph_mum","IDmum_S","ID_stigma","sexorg_mum", "SstigmaX","SstigmaY","SstigmaZ","pop_code_dad","morph_dad", "IDdad_S", "ID_anther",
+                               "sexorg_dad","SantherX","SantherY","SantherZ")
 
-			### Final estimates
+            df.2d$dist.2d <- sqrt((df.2d$SstigmaX-df.2d$SantherX)^2+(df.2d$SstigmaY-df.2d$SantherY)^2+(df.2d$SstigmaZ-df.2d$SantherZ)^2)
+            df.2d$distX.2d <- df.2d$dist.2d/Xr.2
+            rS.2d <- sum(df.2d$distX.2d, na.rm=na.rm)/(p.2*q.2)
+            distXrS.2d <- (df.2d$distX.2d-rS.2d)^2
+            sdrS.2d <- sqrt(sum(distXrS.2d, na.rm=na.rm)/(p.2*q.2))  ###corrected sqrt
 
-			r.2 <- sqrt(rL.2u^2+rS.2d^2)
-			sdr.2 <- (sdrL.2u+sdrS.2d)/2
-			R.2 <- 1-(10*r.2*sdr.2)
-			out.SA <- matrix(c(r.2,R.2),dimnames=list(c("r","R"),POPS[i]))
+            ### Final estimates
 
-			verbSanchez<- c(rL.2u, sdrL.2u, rS.2d, sdrS.2d, r.2, sdr.2, R.2)
-			names(verbSanchez)<-c("rL", "sdrL", "rS", "sdrS", "r", "sdr", "R")
+            r.2 <- sqrt(rL.2u^2+rS.2d^2)
+            sdr.2 <- (sdrL.2u+sdrS.2d)/2
+            R.2 <- 1-(10*r.2*sdr.2)
+            out.SA <- matrix(c(r.2,R.2),dimnames=list(c("r","R"),POPS[i]))
+
+            verbSanchez<- c(rL.2u, sdrL.2u, rS.2d, sdrS.2d, r.2, sdr.2, R.2)
+            names(verbSanchez)<-c("rL", "sdrL", "rS", "sdrS", "r", "sdr", "R")
+
+          }
 
-			}
 
 			###### OUTPUTS
 		ifelse(sanchez,
